@@ -27,7 +27,7 @@
  * list of people on the gedit Team.
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-commands-file.c 6912 2009-02-22 17:00:21Z pborelli $
+ * $Id$
  */
 
 #ifdef HAVE_CONFIG_H
@@ -46,14 +46,12 @@
 #include "gedit-statusbar.h"
 #include "gedit-debug.h"
 #include "gedit-utils.h"
-#include "dialogs/gedit-close-confirmation-dialog.h"
-#include "dialogs/gedit-open-location-dialog.h"
 #include "gedit-file-chooser-dialog.h"
+#include "dialogs/gedit-close-confirmation-dialog.h"
 
 
 /* Defined constants */
 #define GEDIT_OPEN_DIALOG_KEY 		"gedit-open-dialog-key"
-#define GEDIT_OPEN_LOCATION_DIALOG_KEY  "gedit-open-location-dialog-key"
 #define GEDIT_TAB_TO_SAVE_AS  		"gedit-tab-to-save-as"
 #define GEDIT_LIST_OF_TABS_TO_SAVE_AS   "gedit-list-of-tabs-to-save-as"
 #define GEDIT_IS_CLOSING_ALL            "gedit-is-closing-all"
@@ -345,15 +343,32 @@ gedit_commands_load_uris (GeditWindow         *window,
 			  const GSList        *uris,
 			  const GeditEncoding *encoding,
 			  gint                 line_pos)
-{	
+{
 	g_return_val_if_fail (GEDIT_IS_WINDOW (window), 0);
 	g_return_val_if_fail ((uris != NULL) && (uris->data != NULL), 0);
-	
+
 	gedit_debug (DEBUG_COMMANDS);
-	
+
 	return load_uri_list (window, uris, encoding, line_pos, FALSE);
 }
 
+/*
+ * This should become public once we convert all api to GFile:
+ */
+static gint
+gedit_commands_load_files (GeditWindow         *window,
+			   GSList              *files,
+			   const GeditEncoding *encoding,
+			   gint                 line_pos)
+{
+	g_return_val_if_fail (GEDIT_IS_WINDOW (window), 0);
+	g_return_val_if_fail ((files != NULL) && (files->data != NULL), 0);
+
+	gedit_debug (DEBUG_COMMANDS);
+
+	return load_file_list (window, files, encoding, line_pos, FALSE);
+}
+
 /*
  * From the command line we can specify a line position for the
  * first doc. Beside specifying a not existing uri creates a
@@ -386,7 +401,7 @@ open_dialog_response_cb (GeditFileChooserDialog *dialog,
                          gint                    response_id,
                          GeditWindow            *window)
 {
-	GSList              *uris;
+	GSList *files;
 	const GeditEncoding *encoding;
 
 	gedit_debug (DEBUG_COMMANDS);
@@ -398,33 +413,33 @@ open_dialog_response_cb (GeditFileChooserDialog *dialog,
 		return;
 	}
 
-	uris = gtk_file_chooser_get_uris (GTK_FILE_CHOOSER (dialog));
-	g_return_if_fail (uris != NULL);
+	files = gtk_file_chooser_get_files (GTK_FILE_CHOOSER (dialog));
+	g_return_if_fail (files != NULL);
 
 	encoding = gedit_file_chooser_dialog_get_encoding (dialog);
 
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 
 	/* Remember the folder we navigated to */
-	 _gedit_window_set_default_path (window, uris->data);
+	 _gedit_window_set_default_location (window, files->data);
 
-	gedit_commands_load_uris (window,
-				  uris,
-				  encoding,
-				  0);
+	gedit_commands_load_files (window,
+				   files,
+				   encoding,
+				   0);
 
-	g_slist_foreach (uris, (GFunc) g_free, NULL);
-	g_slist_free (uris);
+	g_slist_foreach (files, (GFunc) g_object_unref, NULL);
+	g_slist_free (files);
 }
 
 void
 _gedit_cmd_file_open (GtkAction   *action,
 		      GeditWindow *window)
 {
-	GtkWidget     *open_dialog;
-	gpointer       data;
+	GtkWidget *open_dialog;
+	gpointer data;
 	GeditDocument *doc;
-	gchar         *default_path = NULL;
+	GFile *default_path = NULL;
 
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -460,35 +475,31 @@ _gedit_cmd_file_open (GtkAction   *action,
 	doc = gedit_window_get_active_document (window);
 	if (doc != NULL)
 	{
-		gchar *uri;
+		GFile *file;
 
-		uri = gedit_document_get_uri (doc);
+		file = gedit_document_get_location (doc);
 
-		if ((uri != NULL) &&
-		    gedit_utils_uri_has_file_scheme (uri))
+		if (file != NULL)
 		{
-			default_path = g_path_get_dirname (uri);
-
-			g_return_if_fail (strlen (default_path) >= 5 /* strlen ("file:") */);
-			if (strcmp (default_path, "file:") == 0)
-			{
-				g_free (default_path);
-
-				default_path = g_strdup ("file:///");
-			}
+			default_path = g_file_get_parent (file);
+			g_object_unref (file);
 		}
-
-		g_free (uri);
 	}
 
 	if (default_path == NULL)
-		default_path = g_strdup (_gedit_window_get_default_path (window));
+		default_path = _gedit_window_get_default_location (window);
 
 	if (default_path != NULL)
-		gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (open_dialog),
-							 default_path);
+	{
+		gchar *uri;
 
-	g_free (default_path);
+		uri = g_file_get_uri (default_path);
+		gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (open_dialog),
+							 uri);
+
+		g_free (uri);
+		g_object_unref (default_path);
+	}
 
 	g_signal_connect (open_dialog,
 			  "response",
@@ -498,97 +509,6 @@ _gedit_cmd_file_open (GtkAction   *action,
 	gtk_widget_show (open_dialog);
 }
 
-static void
-open_location_dialog_destroyed (GeditWindow *window,
-				gpointer     data)
-{
-	gedit_debug (DEBUG_COMMANDS);
-
-	g_object_set_data (G_OBJECT (window),
-			   GEDIT_OPEN_LOCATION_DIALOG_KEY,
-			   NULL);
-}
-
-static void
-open_location_dialog_response_cb (GeditOpenLocationDialog *dlg,
-				  gint                    response_id,
-				  GeditWindow             *window)
-{
-	GFile *location;
-	const GeditEncoding *encoding;
-	GSList *uris = NULL;
-
-	gedit_debug (DEBUG_COMMANDS);
-
-	if (response_id != GTK_RESPONSE_OK)
-	{
-		gtk_widget_destroy (GTK_WIDGET (dlg));
-
-		return;
-	}
-
-	location = gedit_open_location_dialog_get_location (dlg);
-	encoding = gedit_open_location_dialog_get_encoding (dlg);
-
-	if (location != NULL)
-	{
-		uris = g_slist_prepend (uris, g_file_get_uri (location));
-
-		g_object_unref (location);
-	}
-
-	gtk_widget_destroy (GTK_WIDGET (dlg));
-
-	if (uris != NULL)
-	{
-		gedit_commands_load_uris (window,
-					  uris,
-					  encoding,
-					  0);
-
-		g_slist_foreach (uris, (GFunc) g_free, NULL);
-		g_slist_free (uris);
-	}
-}
-
-void
-_gedit_cmd_file_open_uri (GtkAction   *action,
-			  GeditWindow *window)
-{
-	GtkWidget *dlg;
-	gpointer   data;
-
-	gedit_debug (DEBUG_COMMANDS);
-
-	data = g_object_get_data (G_OBJECT (window), GEDIT_OPEN_LOCATION_DIALOG_KEY);
-
-	if (data != NULL)
-	{
-		g_return_if_fail (GEDIT_IS_OPEN_LOCATION_DIALOG (data));
-
-		gtk_window_present (GTK_WINDOW (data));
-
-		return;
-	}
-
-	dlg = gedit_open_location_dialog_new (GTK_WINDOW (window));
-
-	g_object_set_data (G_OBJECT (window),
-			   GEDIT_OPEN_LOCATION_DIALOG_KEY,
-			   dlg);
-
-	g_object_weak_ref (G_OBJECT (dlg),
-			   (GWeakNotify) open_location_dialog_destroyed,
-			   window);
-
-	g_signal_connect (dlg,
-			  "response",
-			  G_CALLBACK (open_location_dialog_response_cb),
-			  window);
-
-	gtk_widget_show (dlg);
-}
-
 /* File saving */
 static void file_save_as (GeditTab *tab, GeditWindow *window);
 
@@ -680,11 +600,11 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
                          gint                    response_id,
                          GeditWindow            *window)
 {
-	gchar               *uri;
+	GFile *file;
 	const GeditEncoding *encoding;
-	GeditTab            *tab;
-	gpointer	     data;
-	GSList		    *tabs_to_save_as;
+	GeditTab *tab;
+	gpointer data;
+	GSList *tabs_to_save_as;
 
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -698,8 +618,8 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 		goto save_next_tab;
 	}
 
-	uri = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (dialog));
-	g_return_if_fail (uri != NULL);
+	file = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (dialog));
+	g_return_if_fail (file != NULL);
 
 	encoding = gedit_file_chooser_dialog_get_encoding (dialog);
 
@@ -708,28 +628,32 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 	if (tab != NULL)
 	{
 		GeditDocument *doc;
-		gchar         *uri_for_display;
+		gchar *parse_name;
+		gchar *uri;
 
 		doc = gedit_tab_get_document (tab);
 		g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
 
-		uri_for_display = gedit_utils_uri_for_display (uri);
+		parse_name = g_file_get_parse_name (file);
 
 		gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
 					        window->priv->generic_message_cid,
 					       _("Saving file '%s'\342\200\246"),
-					       uri_for_display);
+					       parse_name);
 
-		g_free (uri_for_display);
+		g_free (parse_name);
 
 		/* let's remember the dir we navigated too,
 		 * even if the saving fails... */
-		 _gedit_window_set_default_path (window, uri);
+		 _gedit_window_set_default_location (window, file);
 
+		// FIXME: pass the GFile to tab when api is there
+		uri = g_file_get_uri (file);
 		_gedit_tab_save_as (tab, uri, encoding);
+		g_free (uri);
 	}
 
-	g_free (uri);
+	g_object_unref (file);
 
 save_next_tab:
 
@@ -812,7 +736,7 @@ file_save_as (GeditTab    *tab,
 	GtkWidget *save_dialog;
 	GtkWindowGroup *wg;
 	GeditDocument *doc;
-	gchar *uri;
+	GFile *file;
 	gboolean uri_set = FALSE;
 	const GeditEncoding *encoding;
 
@@ -846,28 +770,37 @@ file_save_as (GeditTab    *tab,
 
 	/* Set the suggested file name */
 	doc = gedit_tab_get_document (tab);
-	uri = gedit_document_get_uri (doc);
+	file = gedit_document_get_location (doc);
 
-	if ((uri != NULL) &&
-	    gedit_utils_uri_has_file_scheme (uri))
+	if (file != NULL)
 	{
-		uri_set = gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (save_dialog),
-						    uri);
+		uri_set = gtk_file_chooser_set_file (GTK_FILE_CHOOSER (save_dialog),
+						     file,
+						     NULL);
+
+		g_object_unref (file);
 	}
 
-	g_free (uri);
 
 	if (!uri_set)
 	{
-		const gchar *default_path;
+		GFile *default_path;
 		gchar *docname;
 
-		default_path = _gedit_window_get_default_path (window);
+		default_path = _gedit_window_get_default_location (window);
 		docname = gedit_document_get_short_name_for_display (doc);
 
 		if (default_path != NULL)
+		{
+			gchar *uri;
+
+			uri = g_file_get_uri (default_path);
 			gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (save_dialog),
-								 default_path);
+								 uri);
+
+			g_free (uri);
+			g_object_unref (default_path);
+		}
 
 		gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (save_dialog),
 						   docname);
@@ -882,7 +815,6 @@ file_save_as (GeditTab    *tab,
 	gedit_file_chooser_dialog_set_encoding (GEDIT_FILE_CHOOSER_DIALOG (save_dialog),
 						encoding);
 
-
 	g_object_set_data (G_OBJECT (save_dialog),
 			   GEDIT_TAB_TO_SAVE_AS,
 			   tab);
@@ -1085,10 +1017,11 @@ _gedit_cmd_file_save_documents_list (GeditWindow *window,
 }
 
 void
-_gedit_cmd_file_save_all (GtkAction   *action,
-			 GeditWindow *window)
+gedit_commands_save_all_documents (GeditWindow *window)
 {
 	GList *docs;
+	
+	g_return_if_fail (GEDIT_IS_WINDOW (window));
 
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -1099,6 +1032,28 @@ _gedit_cmd_file_save_all (GtkAction   *action,
 	g_list_free (docs);
 }
 
+void
+_gedit_cmd_file_save_all (GtkAction   *action,
+			 GeditWindow *window)
+{
+	gedit_commands_save_all_documents (window);
+}
+
+void
+gedit_commands_save_document (GeditWindow   *window,
+                              GeditDocument *document)
+{
+	GeditTab *tab;
+
+	g_return_if_fail (GEDIT_IS_WINDOW (window));
+	g_return_if_fail (GEDIT_IS_DOCUMENT (document));
+	
+	gedit_debug (DEBUG_COMMANDS);
+	
+	tab = gedit_tab_get_from_document (document);
+	file_save (tab, window);
+}
+
 /* File revert */
 static void
 do_revert (GeditWindow *window,
