@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-window-private.h 6865 2009-01-24 18:02:20Z pborelli $
+ * $Id$
  */
 
 #ifndef __GEDIT_WINDOW_PRIVATE_H__
@@ -70,8 +70,9 @@ struct _GeditWindowPrivate
 	/* Menus & Toolbars */
 	GtkUIManager   *manager;
 	GtkActionGroup *action_group;
-	GtkActionGroup *quit_action_group;
 	GtkActionGroup *always_sensitive_action_group;
+	GtkActionGroup *quit_action_group;
+	GtkActionGroup *panes_action_group;
 	GtkActionGroup *languages_action_group;
 	GtkActionGroup *documents_list_action_group;
 	guint           documents_list_menu_ui_id;
@@ -93,19 +94,19 @@ struct _GeditWindowPrivate
 	gint            height;	
 	GdkWindowState  window_state;
 
-	gint		side_panel_size;
-	gint		bottom_panel_size;
+	gint            side_panel_size;
+	gint            bottom_panel_size;
 
 	GeditWindowState state;
 
-	gint		bottom_panel_item_removed_handler_id;
+	gint            bottom_panel_item_removed_handler_id;
 
 	GtkWindowGroup *window_group;
 
-	gchar          *default_path;
+	GFile          *default_location;
 
-	gboolean	removing_tabs : 1;
-	gboolean	dispose_has_run : 1;
+	gboolean        removing_tabs : 1;
+	gboolean        dispose_has_run : 1;
 };
 
 G_END_DECLS
