@@ -41,14 +41,21 @@ class Placeholder:
                 self.tabstop = tabstop
                 self.set_default(defaults)
                 self.prev_contents = self.default
+                self.set_mark_gravity()
                 
                 if begin:
-                        self.begin = self.buf.create_mark(None, begin, True)
+                        self.begin = self.buf.create_mark(None, begin, self.mark_gravity[0])
                 else:
                         self.begin = None
                 
                 self.end = None
         
+        def __str__(self):
+                return '%s (%s)' % (str(self.__class__), str(self.default))
+
+        def set_mark_gravity(self):
+                self.mark_gravity = [True, False]
+
         def set_default(self, defaults):
                 if not defaults:
                         self.default = None
@@ -95,10 +102,10 @@ class Placeholder:
         
         def run_last(self, placeholders):
                 begin = self.begin_iter()
-                self.end = self.buf.create_mark(None, begin, False)
-                
+                self.end = self.buf.create_mark(None, begin, self.mark_gravity[1])
+
                 if self.default:
-                        insert_with_indent(self.view, begin, self.default, False)
+                        insert_with_indent(self.view, begin, self.default, False, self)
         
         def remove(self, force = False):
                 if self.begin and not self.begin.get_deleted():
@@ -150,7 +157,7 @@ class Placeholder:
                 self.buf.delete(begin, self.end_iter())
 
                 # Insert the text from the mirror
-                insert_with_indent(self.view, begin, text, True)
+                insert_with_indent(self.view, begin, text, True, self)
                 self.buf.end_user_action()
                 
                 self.update_contents()
@@ -163,14 +170,17 @@ class Placeholder:
                         for mirror in self.mirrors:
                                 if not mirror.update(self):
                                         return
-                        
-        # Do something on ending this placeholder
-        def leave(self):
+
+        def update_leave_mirrors(self):
                 # Notify mirrors
                 for mirror in self.leave_mirrors:
                         if not mirror.update(self):
                                 return
 
+        # Do something on ending this placeholder
+        def leave(self):
+               self.update_leave_mirrors()
+
         def find_mirrors(self, text, placeholders):
                 mirrors = []
                 
@@ -234,8 +244,9 @@ class PlaceholderEnd(Placeholder):
                 # any text
                 
                 if not self.default:
+                        self.mark_gravity[0] = False
                         self.buf.delete_mark(self.begin)
-                        self.begin = self.buf.create_mark(None, self.end_iter(), False)
+                        self.begin = self.buf.create_mark(None, self.end_iter(), self.mark_gravity[0])
 
         def enter(self):
                 if self.begin and not self.begin.get_deleted():
@@ -257,6 +268,11 @@ class PlaceholderExpand(Placeholder):
                 self.cmd = s
                 self.instant_update = False
 
+        def __str__(self):
+                s = Placeholder.__str__(self)
+                
+                return s + ' ' + self.cmd
+
         def get_mirrors(self, placeholders):
                 return self.find_mirrors(self.cmd, placeholders)
                 
@@ -266,7 +282,7 @@ class PlaceholderExpand(Placeholder):
 
                 self.ok = True
                 mirrors = self.get_mirrors(placeholders)
-        
+                
                 if mirrors:
                         allDefault = True
                                 
@@ -275,11 +291,12 @@ class PlaceholderExpand(Placeholder):
                                 p.add_mirror(self, not self.instant_update)
                                 self.mirror_text[p.tabstop] = p.default
                                 
-                                if not p.default:
+                                if not p.default and not isinstance(p, PlaceholderExpand):
                                         allDefault = False
                         
                         if allDefault:
                                 self.update(None)
+                                self.default = self.get_text() or None
                 else:
                         self.update(None)
                         self.default = self.get_text() or None
@@ -328,22 +345,27 @@ class PlaceholderExpand(Placeholder):
                 text = self.substitute(self.cmd)
                 
                 if text:
-                        return self.expand(text)
+                        ret = self.expand(text)
+                        
+                        if ret:
+                                self.update_leave_mirrors()
+                else:
+                        ret = True
                 
-                return True
+                return ret
               
         def update(self, mirror):
                 text = None
                 
                 if mirror:
                         self.mirror_text[mirror.tabstop] = mirror.get_text()
-
+                        
                         # Check if all substitutions have been made
                         for tabstop in self.mirror_text:
                                 if tabstop == 0:
                                         continue
 
-                                if not self.mirror_text[tabstop]:
+                                if self.mirror_text[tabstop] == None:
                                         return False
 
                 return self.run_update()
@@ -560,7 +582,7 @@ class PlaceholderEval(PlaceholderExpand):
                                 return False
 
                         if result == None:
-                                sys.stderr.write("%s:\n>> %s\n" % (_('The following python code, run in a snippet, does not return a value'), "\n>> ".join(self.command.split("\n"))))
+                                # sys.stderr.write("%s:\n>> %s\n" % (_('The following python code, run in a snippet, does not return a value'), "\n>> ".join(self.command.split("\n"))))
                                 result = ''
 
                         self.set_text(str(result))
